@@ -2,11 +2,11 @@
 #include <libxslt/xsltutils.h>
 #include <libxml/xpathInternals.h>
 #include "base64.h"
-#include <string.h>
+#include <cstring>
 
 void swft_addFileName( xmlNodePtr node, const char *filename ) {
-	char *name, *b;
-	const char *basename;
+	char *name, *n;
+	const char *basename, *b;
 	int l;
 	
 	// figure basename (filename without path)
@@ -14,13 +14,13 @@ void swft_addFileName( xmlNodePtr node, const char *filename ) {
 	basename = b ? b+1 : filename;
 	
 	l = strlen(basename);
-	name = new char[l];
-	strncpy( name, basename, l );
+	name = new char[l + 1];
+	strncpy( name, basename, l + 1 ); // copy string including null terminator
 	
 	// separate extension (set position of last . as end of string)
-	b = strrchr( name, '.' );
-	if( b ) b[0]=0;
-		
+	n = strrchr( name, '.' );
+	if( n ) n[0]=0;
+	
 	xmlSetProp( node, (const xmlChar *)"name", (const xmlChar *)name );
 	
 	delete[] name;
