@@ -10,7 +10,7 @@
 #include <zlib.h>
 
 #define TMP_STRLEN 0xff
-const char jpeg_header[] = { 0xff, 0xd9, 0xff, 0xd8, 0 };
+const char jpeg_header[] = { (char)0xff, (char)0xd9, (char)0xff, (char)0xd8, 0 };
 
 // defined in swft_import_png
 bool compress( unsigned char *inputBuffer, int inLength, unsigned char *outputBuffer, int *outLength );
@@ -82,7 +82,6 @@ bool getJpegDimensions (FILE *infile, int &image_width, int &image_height) {
 void swft_import_jpeg( xmlXPathParserContextPtr ctx, int nargs ) {
 	xsltTransformContextPtr tctx;
 	char *filename;
-	xsltDocumentPtr xsltdoc;
 	xmlDocPtr doc = NULL;
 	xmlNodePtr node;
 	xmlXPathObjectPtr obj;
@@ -167,10 +166,8 @@ fail:
 void swft_import_jpega( xmlXPathParserContextPtr ctx, int nargs ) {
 	xsltTransformContextPtr tctx;
 	char *filename, *maskfilename;
-	xsltDocumentPtr xsltdoc;
 	xmlDocPtr doc = NULL;
 	xmlNodePtr node;
-	xmlXPathObjectPtr obj;
 	char tmp[TMP_STRLEN];
 	unsigned char *jpegdata = NULL;
 	unsigned char *data = NULL;
